ACTAB Tests
===========
ACTAB uses the `pytest <https://docs.pytest.org/en/7.2.x/>`_ framework for testing.

Tests for modules and classes are in their own directories of the same name.For example for the Tokenizer can be found in /test/Tokenizer.All test modules also need to be listed in actab setup.py.



Running the tests
-----------------
.. code-block:: bash

   ...


